/*
 *				**** WRP CSV ****
 *
 * This is the header file for a CSV ADT
 * it is based on the CSV library by Kernighan & Pike
 * from their book "The Practice of Programming"
 *
 * This version implements the logic as a first class ADT
 * (Abstract Data Type).  It can handle any number of CSV
 * lines from either files or strings.
 *
 */

#define WRPCSV_INVALID	(-11)	/* negative return codes always invalid */
#define WRPCSV_MEMORY	(-12)
#define WRPCSV_EOF	(EOF)
#define WRPCSV_OK       (0)	/* sometimes positive is okay */

int wrpCsvCreate(void);	/* create a new CSV parser */
int wrpCsvReadLine(int id, FILE *fp); /* read line and parse it */
int wrpCsvParseString(int id, char *p); /* parse string */
int wrpCsvGetNumFields(int id);	/* return number of fields */
char *wrpCsvGetField(int id, int ndx); /* return specified field */
int wrpCsvDestroy(int id); /* free up CSV parser */

/* set param values for specific parse engine */
int wrpCsvSetMaxLine(int id, int val);	/* set max size of line */
int wrpCsvSetMaxFields(int id, int val); /* set max number of fields */
int wrpCsvSetDelims(int id, char *delim); /* specify delimeters */

/* set global default values */
int wrpCsvSetDefaultMaxLine(int val);	/* set max size of line */
int wrpCsvSetDefaultMaxFields(int val);	/* set max number of fields */
int wrpCsvSetDefaultDelims(char *delim);	/* set default delimeter chars */
int wrpCsvGetDefaultMaxLine(void);
int wrpCsvGetDefaultMaxFields(void);
char *wrpCsvGetDefaultDelims(void);
int wrpCsvGetMaxEnt(void);   	/* max. number of csv ADTs */
int wrpCsvSetMaxEnt(int val);	/* set new max. number */

char *wrpCsvGetLine(int id);	/* return original line */
char *wrpCsvGetErrMsg(void);	/* most recent error message */

